@@ -174,9 +174,9 @@ static void dialog_cb(GtkAction* action, AccessxStatusApplet* sapplet)
 }
 
 static const GtkActionEntry accessx_status_applet_menu_actions[] = {
-	{"Dialog", GTK_STOCK_PROPERTIES, N_("_Keyboard Accessibility Preferences"), NULL, NULL, G_CALLBACK(dialog_cb)},
-	{"Help", GTK_STOCK_HELP, N_("_Help"), NULL, NULL, G_CALLBACK(help_cb)},
-	{"About", GTK_STOCK_ABOUT, N_("_About"), NULL, NULL, G_CALLBACK(about_cb)}
+	{"Dialog", "document-properties", N_("_Keyboard Accessibility Preferences"), NULL, NULL, G_CALLBACK(dialog_cb)},
+	{"Help", "help-browser", N_("_Help"), NULL, NULL, G_CALLBACK(help_cb)},
+	{"About", "help-about", N_("_About"), NULL, NULL, G_CALLBACK(about_cb)}
 };
 
 static XkbDescPtr accessx_status_applet_get_xkb_desc(AccessxStatusApplet* sapplet)
