@@ -282,10 +282,10 @@ properties_cb (GtkAction  *action,
 		return;
 	}
 
-        pbox = gtk_dialog_new_with_buttons (_("Eyes Preferences"), NULL,
+        pbox = gtk_dialog_new_with_buttons (_("Geyes Preferences"), NULL,
         				     GTK_DIALOG_DESTROY_WITH_PARENT,
-					     GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
-					     GTK_STOCK_HELP, GTK_RESPONSE_HELP,
+					     "gtk-close", GTK_RESPONSE_CLOSE,
+					     "gtk-help", GTK_RESPONSE_HELP,
 					     NULL);
 
 	gtk_window_set_screen (GTK_WINDOW (pbox),
