@@ -108,16 +108,16 @@ static const GtkActionEntry weather_applet_menu_actions [] = {
 	{ "Details", NULL, N_("_Details"),
 	  NULL, NULL,
 	  G_CALLBACK (details_cb) },
-	{ "Update", GTK_STOCK_REFRESH, N_("_Update"),
+	{ "Update", "view-refresh", N_("_Update"),
 	  NULL, NULL,
 	  G_CALLBACK (update_cb) },
-	{ "Props", GTK_STOCK_PROPERTIES, N_("_Preferences"),
+	{ "Props", "document-properties", N_("_Preferences"),
 	  NULL, NULL,
 	  G_CALLBACK (pref_cb) },
-	{ "Help", GTK_STOCK_HELP, N_("_Help"),
+	{ "Help", "help-browser", N_("_Help"),
 	  NULL, NULL,
 	  G_CALLBACK (help_cb) },
-	{ "About", GTK_STOCK_ABOUT, N_("_About"),
+	{ "About", "help-about", N_("_About"),
 	  NULL, NULL,
 	  G_CALLBACK (about_cb) }
 };
